summaryrefslogtreecommitdiffstats
path: root/ingen/client
diff options
context:
space:
mode:
Diffstat (limited to 'ingen/client')
-rw-r--r--ingen/client/BlockModel.hpp (renamed from ingen/client/NodeModel.hpp)30
-rw-r--r--ingen/client/ClientStore.hpp2
-rw-r--r--ingen/client/ObjectModel.hpp2
-rw-r--r--ingen/client/PatchModel.hpp10
-rw-r--r--ingen/client/PluginModel.hpp8
-rw-r--r--ingen/client/PluginUI.hpp28
6 files changed, 40 insertions, 40 deletions
diff --git a/ingen/client/ClientStore.hpp b/ingen/client/ClientStore.hpp
index 42519158..6da7310e 100644
--- a/ingen/client/ClientStore.hpp
+++ b/ingen/client/ClientStore.hpp
@@ -37,7 +37,7 @@ class URIs;
namespace Client {
-class NodeModel;
+class BlockModel;
class ObjectModel;
class PatchModel;
class PluginModel;
diff --git a/ingen/client/ObjectModel.hpp b/ingen/client/ObjectModel.hpp
index 69ad3e22..b51e82e6 100644
--- a/ingen/client/ObjectModel.hpp
+++ b/ingen/client/ObjectModel.hpp
@@ -41,7 +41,7 @@ namespace Client {
class ClientStore;
-/** Base class for all GraphObject models (NodeModel, PatchModel, PortModel).
+/** Base class for all GraphObject models (BlockModel, PatchModel, PortModel).
*
* There are no non-const public methods intentionally, models are not allowed
* to be manipulated directly by anything (but the Store) because of the
diff --git a/ingen/client/PatchModel.hpp b/ingen/client/PatchModel.hpp
index d4c8f511..b4f56799 100644
--- a/ingen/client/PatchModel.hpp
+++ b/ingen/client/PatchModel.hpp
@@ -17,7 +17,7 @@
#ifndef INGEN_CLIENT_PATCHMODEL_HPP
#define INGEN_CLIENT_PATCHMODEL_HPP
-#include "ingen/client/NodeModel.hpp"
+#include "ingen/client/BlockModel.hpp"
#include "raul/SharedPtr.hpp"
namespace Ingen {
@@ -30,7 +30,7 @@ class EdgeModel;
*
* @ingroup IngenClient
*/
-class PatchModel : public NodeModel
+class PatchModel : public BlockModel
{
public:
/* WARNING: Copy constructor creates a shallow copy WRT connections */
@@ -45,8 +45,8 @@ public:
uint32_t internal_poly() const;
// Signals
- INGEN_SIGNAL(new_node, void, SharedPtr<NodeModel>);
- INGEN_SIGNAL(removed_node, void, SharedPtr<NodeModel>);
+ INGEN_SIGNAL(new_block, void, SharedPtr<BlockModel>);
+ INGEN_SIGNAL(removed_block, void, SharedPtr<BlockModel>);
INGEN_SIGNAL(new_edge, void, SharedPtr<EdgeModel>);
INGEN_SIGNAL(removed_edge, void, SharedPtr<EdgeModel>);
@@ -54,7 +54,7 @@ private:
friend class ClientStore;
PatchModel(URIs& uris, const Raul::Path& patch_path)
- : NodeModel(
+ : BlockModel(
uris, Raul::URI("http://drobilla.net/ns/ingen#Patch"), patch_path)
{
}
diff --git a/ingen/client/PluginModel.hpp b/ingen/client/PluginModel.hpp
index 13375c95..7475e57a 100644
--- a/ingen/client/PluginModel.hpp
+++ b/ingen/client/PluginModel.hpp
@@ -38,7 +38,7 @@ class URIs;
namespace Client {
class PatchModel;
-class NodeModel;
+class BlockModel;
class PluginUI;
/** Model for a plugin available for loading.
@@ -57,7 +57,7 @@ public:
virtual const Raul::Atom& get_property(const Raul::URI& key) const;
- Raul::Symbol default_node_symbol() const;
+ Raul::Symbol default_block_symbol() const;
std::string human_name() const;
std::string port_human_name(uint32_t index) const;
@@ -74,8 +74,8 @@ public:
bool has_ui() const;
- SharedPtr<PluginUI> ui(Ingen::World* world,
- SharedPtr<const NodeModel> node) const;
+ SharedPtr<PluginUI> ui(Ingen::World* world,
+ SharedPtr<const BlockModel> block) const;
const std::string& icon_path() const;
static std::string get_lv2_icon_path(const LilvPlugin* plugin);
diff --git a/ingen/client/PluginUI.hpp b/ingen/client/PluginUI.hpp
index 1c45bd56..60403570 100644
--- a/ingen/client/PluginUI.hpp
+++ b/ingen/client/PluginUI.hpp
@@ -32,7 +32,7 @@ class World;
namespace Client {
-class NodeModel;
+class BlockModel;
/** Model for a plugin available for loading.
*
@@ -42,9 +42,9 @@ class PluginUI {
public:
~PluginUI();
- static SharedPtr<PluginUI> create(Ingen::World* world,
- SharedPtr<const NodeModel> node,
- const LilvPlugin* plugin);
+ static SharedPtr<PluginUI> create(Ingen::World* world,
+ SharedPtr<const BlockModel> block,
+ const LilvPlugin* plugin);
SuilWidget get_widget();
@@ -55,18 +55,18 @@ public:
bool is_resizable() const;
- Ingen::World* world() const { return _world; }
- SharedPtr<const NodeModel> node() const { return _node; }
+ Ingen::World* world() const { return _world; }
+ SharedPtr<const BlockModel> block() const { return _block; }
private:
- PluginUI(Ingen::World* world,
- SharedPtr<const NodeModel> node,
- const LilvNode* ui_node);
-
- Ingen::World* _world;
- SharedPtr<const NodeModel> _node;
- SuilInstance* _instance;
- LilvNode* _ui_node;
+ PluginUI(Ingen::World* world,
+ SharedPtr<const BlockModel> block,
+ const LilvNode* ui_node);
+
+ Ingen::World* _world;
+ SharedPtr<const BlockModel> _block;
+ SuilInstance* _instance;
+ LilvNode* _ui_node;
static SuilHost* ui_host;
diff --git a/ingen/client/NodeModel.hpp b/ingen/client/BlockModel.hpp
index 9f2fab6e..dbb0faf3 100644
--- a/ingen/client/NodeModel.hpp
+++ b/ingen/client/BlockModel.hpp
@@ -14,8 +14,8 @@
along with Ingen. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef INGEN_CLIENT_NODEMODEL_HPP
-#define INGEN_CLIENT_NODEMODEL_HPP
+#ifndef INGEN_CLIENT_BLOCKMODEL_HPP
+#define INGEN_CLIENT_BLOCKMODEL_HPP
#include <cstdlib>
#include <string>
@@ -38,15 +38,15 @@ namespace Client {
class PluginModel;
class ClientStore;
/** Node model class, used by the client to store engine's state.
*
* @ingroup IngenClient
*/
-class NodeModel : public ObjectModel
+class BlockModel : public ObjectModel
{
public:
- NodeModel(const NodeModel& copy);
- virtual ~NodeModel();
+ BlockModel(const BlockModel& copy);
+ virtual ~BlockModel();
GraphType graph_type() const { return GraphObject::PATCH; }
@@ -79,13 +79,13 @@ public:
protected:
friend class ClientStore;
- NodeModel(URIs& uris,
- const Raul::URI& plugin_uri,
- const Raul::Path& path);
- NodeModel(URIs& uris,
- SharedPtr<PluginModel> plugin,
- const Raul::Path& path);
- explicit NodeModel(const Raul::Path& path);
+ BlockModel(URIs& uris,
+ const Raul::URI& plugin_uri,
+ const Raul::Path& path);
+ BlockModel(URIs& uris,
+ SharedPtr<PluginModel> plugin,
+ const Raul::Path& path);
+ explicit BlockModel(const Raul::Path& path);
void add_child(SharedPtr<ObjectModel> c);
bool remove_child(SharedPtr<ObjectModel> c);
@@ -98,7 +98,7 @@ protected:
Ports _ports; ///< Vector of ports
Raul::URI _plugin_uri; ///< Plugin URI (if PluginModel is unknown)
- SharedPtr<PluginModel> _plugin; ///< The plugin this node is an instance of
+ SharedPtr<PluginModel> _plugin; ///< The plugin this block is an instance of
private:
mutable uint32_t _num_values; ///< Size of _min_values and _max_values
@@ -109,4 +109,4 @@ private:
} // namespace Client
} // namespace Ingen
-#endif // INGEN_CLIENT_NODEMODEL_HPP
+#endif // INGEN_CLIENT_BLOCKMODEL_HPP
@@ -38,15 +38,15 @@ namespace Client {
class PluginModel;
class ClientStore;
-/** Node model class, used by the client to store engine's state.
+/** Block model class, used by the client to store engine's state.
*
* @ingroup IngenClient